import type { Recommendation } from '../types/index.js';
/**
 * 推荐引擎
 * 提供基于多种算法的智能内容和用户推荐
 */
export declare class RecommendationEngine {
    /**
     * 生成内容推荐
     */
    generateContentRecommendations(params?: {
        user_id?: string;
        user_interests?: string[];
        content_type?: 'article' | 'pin' | 'both';
        algorithm?: 'collaborative' | 'content_based' | 'hybrid' | 'trending';
        limit?: number;
        min_quality_score?: number;
    }): Promise<Recommendation[]>;
    /**
     * 协同过滤推荐
     */
    private collaborativeFiltering;
    /**
     * 基于内容的过滤推荐
     */
    private contentBasedFiltering;
    /**
     * 基于趋势的推荐
     */
    private trendingBasedRecommendations;
    /**
     * 混合推荐算法
     */
    private hybridRecommendations;
    /**
     * 找到相似用户
     */
    private findSimilarUsers;
    /**
     * 从相似用户获取内容
     */
    private getContentFromSimilarUsers;
    /**
     * 获取文章推荐
     */
    private getArticleRecommendations;
    /**
     * 获取沸点推荐
     */
    private getPinRecommendations;
    /**
     * 根据话题查找文章
     */
    private findArticlesByTopic;
    /**
     * 根据话题查找沸点
     */
    private findPinsByTopic;
    /**
     * 计算兴趣匹配分数
     */
    private calculateInterestScore;
    /**
     * 计算沸点兴趣匹配分数
     */
    private calculatePinInterestScore;
    /**
     * 生成推荐理由
     */
    private generateRecommendationReason;
    /**
     * 生成沸点推荐理由
     */
    private generatePinRecommendationReason;
    /**
     * 按质量过滤推荐
     */
    private filterByQuality;
    /**
     * 推荐多样性优化
     */
    private diversifyRecommendations;
    /**
     * 去重推荐
     */
    private deduplicateRecommendations;
    /**
     * 生成用户推荐
     */
    generateUserRecommendations(params?: {
        user_id?: string;
        user_interests?: string[];
        limit?: number;
        algorithm?: 'similarity' | 'influence' | 'hybrid';
    }): Promise<any[]>;
    /**
     * 基于相似度的用户推荐
     */
    private similarityBasedUserRecommendations;
    /**
     * 基于影响力的用户推荐
     */
    private influenceBasedUserRecommendations;
    /**
     * 混合用户推荐
     */
    private hybridUserRecommendations;
    /**
     * 计算用户影响力分数
     */
    private calculateUserInfluenceScore;
    /**
     * 生成影响力推荐理由
     */
    private generateInfluenceReason;
    /**
     * 去重用户推荐
     */
    private deduplicateUserRecommendations;
    /**
     * 实时推荐更新
     */
    updateRecommendations(userId: string): Promise<{
        user_id: string;
        updated_at: string;
        recommendations: Recommendation[];
        recommendation_count: number;
    }>;
}
export declare const recommendationEngine: RecommendationEngine;
