import type { ArticleInfo, ArticleListParams, Category, Tag } from '../types/index.js';
/**
 * 文章相关API
 */
export declare class ArticleApi {
    /**
     * 获取文章列表（带缓存优化）
     */
    getArticleList(params?: ArticleListParams): Promise<any>;
    /**
     * 获取推荐文章
     */
    getRecommendedArticles(limit?: number): Promise<any>;
    /**
     * 获取最新文章
     */
    getLatestArticles(limit?: number): Promise<any>;
    /**
     * 获取热榜文章
     */
    getHotArticles(days?: 3 | 7 | 30, limit?: number): Promise<any>;
    /**
     * 按分类获取文章
     */
    getArticlesByCategory(_categoryId: string, limit?: number): Promise<any>;
    /**
     * 获取分类列表
     */
    getCategoryList(): Promise<Category[]>;
    /**
     * 获取标签列表
     */
    getTagList(): Promise<Tag[]>;
    /**
     * 搜索文章（基于标题和内容）
     */
    searchArticles(keyword: string, limit?: number): Promise<{
        articles: any;
        pins: never[];
        total: any;
        cursor: any;
        has_more: boolean;
    }>;
    /**
     * 获取文章详细信息
     */
    getArticleDetail(articleId: string): Promise<any>;
    /**
     * 获取默认分类（当API失败时使用）
     */
    private getDefaultCategories;
    /**
     * 批量获取文章（用于数据分析）
     */
    getBatchArticles(batchSize?: number, maxBatches?: number): Promise<ArticleInfo[]>;
}
export declare const articleApi: ArticleApi;
