import type { PinInfo, PinListParams, Topic } from '../types/index.js';
/**
 * 沸点相关API
 */
export declare class PinApi {
    /**
     * 获取沸点列表
     */
    getPinList(params?: PinListParams): Promise<{
        pins: PinInfo[];
        cursor: string | undefined;
        has_more: boolean;
        count: number;
    }>;
    /**
     * 获取最新沸点
     */
    getLatestPins(limit?: number): Promise<{
        pins: PinInfo[];
        cursor: string | undefined;
        has_more: boolean;
        count: number;
    }>;
    /**
     * 按话题获取沸点
     */
    getPinsByTopic(topicId: string, limit?: number): Promise<{
        pins: PinInfo[];
        cursor: string | undefined;
        has_more: boolean;
        count: number;
    }>;
    /**
     * 获取热门话题列表
     */
    getHotTopics(): Promise<{
        pin_count: number;
        topic_id: string;
        title: string;
        pic: string;
    }[]>;
    /**
     * 搜索沸点
     */
    searchPins(keyword: string, limit?: number): Promise<{
        articles: never[];
        pins: PinInfo[];
        total: number;
        cursor: string | undefined;
        has_more: boolean;
    }>;
    /**
     * 获取沸点详细信息
     */
    getPinDetail(pinId: string): Promise<PinInfo>;
    /**
     * 获取用户沸点
     */
    getUserPins(userId: string, limit?: number): Promise<{
        pins: PinInfo[];
        cursor: string | undefined;
        has_more: boolean;
        count: number;
        user_id: string;
    }>;
    /**
     * 获取热门沸点（基于互动数据）
     */
    getHotPins(limit?: number): Promise<{
        pins: {
            heat_score: number;
            msg_id: string;
            msg_info: import("../types/index.js").Pin;
            author_user_info: import("../types/index.js").UserInfo;
            topic: Topic;
            user_interact: import("../types/index.js").UserInteract;
        }[];
        cursor: string | undefined;
        has_more: boolean;
        count: number;
    }>;
    /**
     * 批量获取沸点（用于数据分析）
     */
    getBatchPins(batchSize?: number, maxBatches?: number): Promise<PinInfo[]>;
    /**
     * 获取沸点统计信息
     */
    getPinStats(pins?: PinInfo[]): Promise<{
        total_pins: number;
        total_diggs: number;
        total_comments: number;
        avg_diggs: number;
        avg_comments: number;
        top_topics: Array<{
            topic: string;
            count: number;
        }>;
        active_users: Array<{
            user_name: string;
            pin_count: number;
        }>;
    }>;
}
export declare const pinApi: PinApi;
