/**
 * 分析协调服务
 * 提供跨模块的数据分析和聚合功能
 */
export declare class AnalyticsService {
    private articleService;
    private pinService;
    /**
     * 生成综合趋势报告
     */
    generateTrendReport(timeRange?: number): Promise<{
        time_range_hours: number;
        analysis_time: string;
        article_trends: {
            total_articles: number;
            tag_trends: {
                heat_score: number;
                count: number;
                total_engagement: number;
                avg_engagement: number;
                growth_rate: number;
                tag: string;
            }[];
            category_trends: {
                avg_engagement: number;
                count: number;
                total_engagement: number;
                avg_quality_score: number;
                category: string;
            }[];
            hotness_trends: {
                hour: number;
                article_count: number;
                avg_hotness: number;
                total_engagement: any;
            }[];
            top_articles: {
                article_id: any;
                title: any;
                author: any;
                engagement: any;
                quality_score: number;
            }[];
        };
        pin_trends: {
            total_pins: number;
            content_type_trends: {
                content_type: string;
                count: number;
                percentage: number;
            }[];
            engagement_trends: {
                hour: number;
                pin_count: number;
                total_diggs: any;
                total_comments: any;
                avg_engagement: number;
            }[];
            sentiment_trends: {
                sentiment: string;
                count: number;
                percentage: number;
            }[];
            viral_pins: {
                pin_id: any;
                content: string;
                author: any;
                engagement: any;
                viral_potential: number;
            }[];
        };
        topic_analysis: {
            time_range_hours: number;
            total_topics: number;
            total_pins: number;
            trending_topics: {
                heat_score: number;
                topic: import("../types/index.js").Topic;
                pin_count: number;
                total_engagement: number;
                avg_engagement: number;
                growth_rate: number;
            }[];
            analysis_time: string;
        };
        cross_platform_trends: any[];
        trend_predictions: {
            topic: any;
            prediction: "rising" | "stable" | "declining";
            confidence: number;
            recommended_actions: string[];
        }[];
        summary: {
            total_trending_topics: number;
            strong_trends_count: number;
            top_trend: {
                topic: any;
                strength: any;
                score: any;
            } | null;
            trend_diversity: "low" | "medium" | "high";
            overall_activity_level: "low" | "medium" | "high";
        };
    }>;
    /**
     * 分析文章趋势
     */
    private analyzeArticleTrends;
    /**
     * 分析沸点趋势
     */
    private analyzePinTrends;
    /**
     * 分析标签趋势
     */
    private analyzeTagTrends;
    /**
     * 分析分类趋势
     */
    private analyzeCategoryTrends;
    /**
     * 分析热度趋势
     */
    private analyzeHotnessTrends;
    /**
     * 获取热门文章
     */
    private getTopArticles;
    /**
     * 分析内容类型趋势
     */
    private analyzeContentTypeTrends;
    /**
     * 分析互动趋势
     */
    private analyzeEngagementTrends;
    /**
     * 分析情感趋势
     */
    private analyzeSentimentTrends;
    /**
     * 获取病毒式传播沸点
     */
    private getViralPins;
    /**
     * 识别跨平台趋势
     */
    private identifyCrossPlatformTrends;
    /**
     * 计算趋势强度
     */
    private calculateTrendStrength;
    /**
     * 生成趋势预测
     */
    private generateTrendPredictions;
    /**
     * 预测趋势方向
     */
    private predictTrendDirection;
    /**
     * 计算预测置信度
     */
    private calculatePredictionConfidence;
    /**
     * 生成推荐行动
     */
    private generateRecommendedActions;
    /**
     * 生成趋势摘要
     */
    private generateTrendSummary;
    /**
     * 计算趋势多样性
     */
    private calculateTrendDiversity;
    /**
     * 评估整体活跃度
     */
    private assessOverallActivityLevel;
    /**
     * 生成内容推荐
     */
    generateContentRecommendations(params?: {
        user_interests?: string[];
        content_type?: 'article' | 'pin' | 'both';
        limit?: number;
    }): Promise<any[]>;
    /**
     * 生成平台洞察报告
     */
    generatePlatformInsights(): Promise<{
        platform_health: "excellent" | "good" | "fair" | "poor";
        content_ecosystem: {
            content_balance: "balanced" | "article_heavy" | "pin_heavy";
            topic_coverage: any;
            engagement_distribution: {
                high_engagement_content_ratio: number;
                medium_engagement_content_ratio: number;
                low_engagement_content_ratio: number;
            };
            content_quality_trend: "stable" | "declining" | "improving";
        };
        user_engagement: {
            active_users_estimate: number;
            content_creators: number;
            avg_engagement_rate: number;
            user_growth_rate: number;
        };
        growth_opportunities: string[];
        recommendations: string[];
        report_time: string;
    }>;
    /**
     * 分析平台用户统计
     */
    private analyzePlatformUserStats;
    /**
     * 评估平台健康度
     */
    private assessPlatformHealth;
    /**
     * 分析内容生态系统
     */
    private analyzeContentEcosystem;
    /**
     * 评估内容平衡性
     */
    private assessContentBalance;
    /**
     * 分析参与度分布
     */
    private analyzeEngagementDistribution;
    /**
     * 评估内容质量趋势
     */
    private assessContentQualityTrend;
    /**
     * 识别增长机会
     */
    private identifyGrowthOpportunities;
    /**
     * 生成平台建议
     */
    private generatePlatformRecommendations;
}
export declare const analyticsService: AnalyticsService;
