import { ArticleInfo, EnhancedArticleInfo, ContentQuality, Recommendation, TagTrend, CategoryTrend, HotnessTrend } from '../types/index.js';
export declare class ArticleService {
    private config;
    private articleApi;
    constructor();
    /**
     * 获取文章列表
     */
    getArticles(sortType?: number, limit?: number, categoryId?: string, includeQualityScore?: boolean): Promise<{
        articles: EnhancedArticleInfo[];
        total: number;
        cursor?: string;
        has_more: boolean;
    }>;
    /**
     * 搜索文章
     */
    searchArticles(keyword: string, limit?: number, includeAnalysis?: boolean): Promise<{
        articles: EnhancedArticleInfo[];
        total: number;
    }>;
    /**
     * 分析文章质量
     */
    analyzeQuality(articleId: string, includePredictions?: boolean): Promise<ContentQuality>;
    /**
     * 获取推荐文章
     */
    getRecommendations(userInterests: string[], limit?: number): Promise<Recommendation[]>;
    /**
     * 获取热门文章
     */
    getTrendingArticles(limit?: number, timeRange?: number, category?: string): Promise<{
        articles: EnhancedArticleInfo[];
        trend_info: {
            time_range: number;
            total_articles: number;
            avg_engagement: number;
            top_tags: string[];
        };
    }>;
    /**
     * 分析趋势
     */
    analyzeTrends(timeRange?: number): Promise<{
        tag_trends: TagTrend[];
        category_trends: CategoryTrend[];
        hotness_trends: HotnessTrend[];
        top_articles: ArticleInfo[];
    }>;
    /**
     * 计算文章质量评分
     */
    calculateQualityScore(articleInfo: ArticleInfo): number;
    private calculateEngagementRate;
    private calculateContentDepth;
    private calculateOriginalityScore;
    private calculateFeedbackScore;
    private predictPerformance;
    private getTimeMultiplier;
    private calculateHeatGrowthRate;
    private calculateMomentumScore;
    private getTopTags;
    private analyzeTagTrends;
    private analyzeCategoryTrends;
    private analyzeHotnessTrends;
    private getTopArticles;
    private calculateGrowthRate;
    private determineTrendDirection;
    private calculateAvgQualityScore;
    private calculateGrowthMomentum;
    private groupByTimeSlots;
    private generateRecommendationReason;
    private calculateInterestScore;
}
