import type { UserInfo, UserProfile } from '../types/index.js';
/**
 * 用户业务逻辑服务
 * 提供用户数据的高级处理和分析功能
 */
export declare class UserService {
    /**
     * 构建用户画像
     */
    buildUserProfile(userId: string): Promise<UserProfile>;
    /**
     * 分析用户活动模式
     */
    private analyzeActivityPattern;
    /**
     * 估算活跃时间
     */
    private estimateActiveHours;
    /**
     * 识别专业领域
     */
    private identifyExpertiseAreas;
    /**
     * 计算用户影响力分数
     */
    calculateInfluenceScore(userInfo: UserInfo): number;
    /**
     * 计算内容质量评分
     */
    private calculateContentQualityScore;
    /**
     * 计算用户参与度评分
     */
    private calculateUserEngagementScore;
    /**
     * 用户相似度计算
     */
    calculateUserSimilarity(userId1: string, userId2: string): Promise<number>;
    /**
     * 计算兴趣相似度
     */
    private calculateInterestSimilarity;
    /**
     * 计算专业领域相似度
     */
    private calculateExpertiseSimilarity;
    /**
     * 计算活动模式相似度
     */
    private calculateActivitySimilarity;
    /**
     * 获取用户推荐
     */
    getUserRecommendations(userId: string, limit?: number): Promise<{
        user_id: string;
        user_name: string;
        reason: string;
        confidence: number;
        similarity_score: number;
        influence_score: number;
    }[]>;
    /**
     * 生成用户推荐理由
     */
    private generateUserRecommendationReason;
    /**
     * 生成用户分析报告
     */
    generateUserReport(userId: string): Promise<{
        user_id: string;
        basic_info: {
            user_name: string;
            level: number;
            company: string;
            job_title: string;
        };
        statistics: {
            level: number;
            power: number;
            followee_count: number;
            follower_count: number;
            post_article_count: number;
            post_shortmsg_count: number;
            got_digg_count: number;
            got_view_count: number;
        };
        influence_analysis: {
            influence_score: number;
            ranking_estimate: string;
            strengths: string[];
            growth_potential: string;
        };
        profile_analysis: UserProfile;
        recommendations: {
            content_suggestions: string[];
            engagement_tips: string[];
        };
        report_time: string;
    }>;
    /**
     * 估算用户排名
     */
    private estimateUserRanking;
    /**
     * 识别用户优势
     */
    private identifyUserStrengths;
    /**
     * 评估成长潜力
     */
    private assessGrowthPotential;
    /**
     * 生成内容建议
     */
    private generateContentSuggestions;
    /**
     * 生成互动建议
     */
    private generateEngagementTips;
}
export declare const userService: UserService;
